@@ -57,17 +57,19 @@ class _RequestContext:
         self._response: Optional[ClientResponse] = None
 
     def _is_status_code_ok(self, code: int) -> bool:
-        return code not in self._retry_options.statuses and code < 500
+        if code >= 500 and self._retry_options.retry_all_server_errors:
+            return False
+        return code not in self._retry_options.statuses
 
     async def _do_request(self) -> ClientResponse:
         current_attempt = 0
         while True:
-            current_attempt += 1
-            self._logger.debug("Attempt {} out of {}".format(current_attempt, self._retry_options.attempts))
-            if current_attempt > 1:
+            self._logger.debug(f"Attempt {current_attempt+1} out of {self._retry_options.attempts}")
+            if current_attempt > 0:
                 retry_wait = self._retry_options.get_timeout(current_attempt)
                 await asyncio.sleep(retry_wait)
 
+            current_attempt += 1
             try:
                 response: ClientResponse = await self._request(
                     self._method,
